#!/bin/sh

# avoid "EV does not work with ithreads" error, 
# see http://mojolicio.us/perldoc/Mojolicious/Guides/FAQ#What-does-the-error-EV-does-not-work-with-ithreads-mean
export MOJO_REACTOR=Mojo::Reactor::Poll

isotovideo.real
